departments = {
    "Amazonas": {
        "dane_code":"91",
        "municipalities":{
            "Miriti Paraná":{"dane_code":"91460"},
            "Leticia":{"dane_code":"91001"},
            "El Encanto":{"dane_code":"91263"},
            "La Chorrera":{"dane_code":"91405"},
            "La Pedrera":{"dane_code":"91407"},
            "La Victoria":{"dane_code":"91430"},
            "Puerto Arica":{"dane_code":"91536"},
            "Puerto Nariño":{"dane_code":"91540"},
            "Puerto Santander":{"dane_code":"91669"},
            "Tarapacá":{"dane_code":"91798"},
        }
    },
    "Antioquia": {
        "dane_code":"05",
        "municipalities":{
            "Medellín":{"dane_code":"05001"},
            "Abejorral":{"dane_code":"05002"},
            "Abriaquí":{"dane_code":"05004"},
            "Alejandría":{"dane_code":"05021"},
            "Amagá":{"dane_code":"05030"},
            "Amalfi":{"dane_code":"05031"},
            "Andes":{"dane_code":"05034"},
            "Angelópolis":{"dane_code":"05036"},
            "Angostura":{"dane_code":"05038"},
            "Anorí":{"dane_code":"05040"},
            "Anza":{"dane_code":"05044"},
            "Apartadó":{"dane_code":"05045"},
            "Arboletes":{"dane_code":"05051"},
            "Argelia":{"dane_code":"05055"},
            "Armenia":{"dane_code":"05059"},
            "Barbosa":{"dane_code":"05079"},
            "Bello":{"dane_code":"05088"},
            "Betania":{"dane_code":"05091"},
            "Betulia":{"dane_code":"05093"},
            "Ciudad Bolívar":{"dane_code":"05101"},
            "Briceño":{"dane_code":"05107"},
            "Buriticá":{"dane_code":"05113"},
            "Cáceres":{"dane_code":"05120"},
            "Caicedo":{"dane_code":"05125"},
            "Caldas":{"dane_code":"05129"},
            "Campamento":{"dane_code":"05134"},
            "Cañasgordas":{"dane_code":"05138"},
            "Caracolí":{"dane_code":"05142"},
            "Caramanta":{"dane_code":"05145"},
            "Carepa":{"dane_code":"05147"},
            "Carolina":{"dane_code":"05150"},
            "Caucasia":{"dane_code":"05154"},
            "Chigorodó":{"dane_code":"05172"},
            "Cisneros":{"dane_code":"05190"},
            "Cocorná":{"dane_code":"05197"},
            "Concepción":{"dane_code":"05206"},
            "Concordia":{"dane_code":"05209"},
            "Copacabana":{"dane_code":"05212"},
            "Dabeiba":{"dane_code":"05234"},
            "Don Matías":{"dane_code":"05237"},
            "Ebéjico":{"dane_code":"05240"},
            "El Bagre":{"dane_code":"05250"},
            "Entrerrios":{"dane_code":"05264"},
            "Envigado":{"dane_code":"05266"},
            "Fredonia":{"dane_code":"05282"},
            "Giraldo":{"dane_code":"05306"},
            "Girardota":{"dane_code":"05308"},
            "Gómez Plata":{"dane_code":"05310"},
            "Guadalupe":{"dane_code":"05315"},
            "Guarne":{"dane_code":"05318"},
            "Guatapé":{"dane_code":"05321"},
            "Heliconia":{"dane_code":"05347"},
            "Hispania":{"dane_code":"05353"},
            "Itagui":{"dane_code":"05360"},
            "Ituango":{"dane_code":"05361"},
            "Jericó":{"dane_code":"05368"},
            "La Ceja":{"dane_code":"05376"},
            "La Estrella":{"dane_code":"05380"},
            "La Pintada":{"dane_code":"05390"},
            "La Unión":{"dane_code":"05400"},
            "Liborina":{"dane_code":"05411"},
            "Maceo":{"dane_code":"05425"},
            "Marinilla":{"dane_code":"05440"},
            "Montebello":{"dane_code":"05467"},
            "Murindó":{"dane_code":"05475"},
            "Mutatá":{"dane_code":"05480"},
            "Nariño":{"dane_code":"05483"},
            "Necoclí":{"dane_code":"05490"},
            "Nechí":{"dane_code":"05495"},
            "Olaya":{"dane_code":"05501"},
            "Peñol":{"dane_code":"05541"},
            "Peque":{"dane_code":"05543"},
            "Pueblorrico":{"dane_code":"05576"},
            "Puerto Berrío":{"dane_code":"05579"},
            "Puerto Nare":{"dane_code":"05585"},
            "Puerto Triunfo":{"dane_code":"05591"},
            "Remedios":{"dane_code":"05604"},
            "Retiro":{"dane_code":"05607"},
            "Rionegro":{"dane_code":"05615"},
            "Sabanalarga":{"dane_code":"05628"},
            "Sabaneta":{"dane_code":"05631"},
            "Salgar":{"dane_code":"05642"},
            "San Francisco":{"dane_code":"05652"},
            "San Jerónimo":{"dane_code":"05656"},
            "San Luis":{"dane_code":"05660"},
            "San Pedro":{"dane_code":"05664"},
            "San Rafael":{"dane_code":"05667"},
            "San Roque":{"dane_code":"05670"},
            "San Vicente":{"dane_code":"05674"},
            "Santa Bárbara":{"dane_code":"05679"},
            "Santo Domingo":{"dane_code":"05690"},
            "El Santuario":{"dane_code":"05697"},
            "Segovia":{"dane_code":"05736"},
            "Sopetrán":{"dane_code":"05761"},
            "Támesis":{"dane_code":"05789"},
            "Tarazá":{"dane_code":"05790"},
            "Tarso":{"dane_code":"05792"},
            "Titiribí":{"dane_code":"05809"},
            "Toledo":{"dane_code":"05819"},
            "Turbo":{"dane_code":"05837"},
            "Uramita":{"dane_code":"05842"},
            "Urrao":{"dane_code":"05847"},
            "Valdivia":{"dane_code":"05854"},
            "Valparaíso":{"dane_code":"05856"},
            "Vegachí":{"dane_code":"05858"},
            "Venecia":{"dane_code":"05861"},
            "Yalí":{"dane_code":"05885"},
            "Yarumal":{"dane_code":"05887"},
            "Yolombó":{"dane_code":"05890"},
            "Yondó":{"dane_code":"05893"},
            "Zaragoza":{"dane_code":"05895"},
            "Frontino":{"dane_code":"05284"},
            "Granada":{"dane_code":"05313"},
            "Jardín":{"dane_code":"05364"},
            "Sonsón":{"dane_code":"05756"},
            "Belmira":{"dane_code":"05086"},
            "San Pedro de Uraba":{"dane_code":"05665"},
            "Santafé de Antioquia":{"dane_code":"05042"},
            "Santa Rosa de Osos":{"dane_code":"05686"},
            "San Andrés de Cuerquía":{"dane_code":"05647"},
        }
    },
    "Arauca": {
        "dane_code":"81",
        "municipalities":{
            "Arauquita":{"dane_code":"81065"},
            "Cravo Norte":{"dane_code":"81220"},
            "Fortul":{"dane_code":"81300"},
            "Puerto Rondón":{"dane_code":"81591"},
            "Saravena":{"dane_code":"81736"},
            "Tame":{"dane_code":"81794"},
            "Arauca":{"dane_code":"81001"},
        },
    },
    "Atlántico": {
        "dane_code":"08",
        "municipalities":{
            "Barranquilla":{"dane_code":"08001"},
            "Baranoa":{"dane_code":"08078"},
            "Candelaria":{"dane_code":"08141"},
            "Galapa":{"dane_code":"08296"},
            "Luruaco":{"dane_code":"08421"},
            "Malambo":{"dane_code":"08433"},
            "Manatí":{"dane_code":"08436"},
            "Piojó":{"dane_code":"08549"},
            "Polonuevo":{"dane_code":"08558"},
            "Sabanagrande":{"dane_code":"08634"},
            "Sabanalarga":{"dane_code":"08638"},
            "Santa Lucía":{"dane_code":"08675"},
            "Santo Tomás":{"dane_code":"08685"},
            "Soledad":{"dane_code":"08758"},
            "Suan":{"dane_code":"08770"},
            "Tubará":{"dane_code":"08832"},
            "Usiacurí":{"dane_code":"08849"},
            "Repelón":{"dane_code":"08606"},
            "Puerto Colombia":{"dane_code":"08573"},
            "Ponedera":{"dane_code":"08560"},
            "Juan de Acosta":{"dane_code":"08372"},
            "Palmar de Varela":{"dane_code":"08520"},
        }
    },
    "Bolívar": {
        "dane_code":"13",
        "municipalities":{
            "El Peñón":{"dane_code":"13268"},
            "Achí":{"dane_code":"13006"},
            "Arenal":{"dane_code":"13042"},
            "Arjona":{"dane_code":"13052"},
            "Arroyohondo":{"dane_code":"13062"},
            "Calamar":{"dane_code":"13140"},
            "Cantagallo":{"dane_code":"13160"},
            "Cicuco":{"dane_code":"13188"},
            "Córdoba":{"dane_code":"13212"},
            "Clemencia":{"dane_code":"13222"},
            "El Guamo":{"dane_code":"13248"},
            "Magangué":{"dane_code":"13430"},
            "Mahates":{"dane_code":"13433"},
            "Margarita":{"dane_code":"13440"},
            "Montecristo":{"dane_code":"13458"},
            "Mompós":{"dane_code":"13468"},
            "Morales":{"dane_code":"13473"},
            "Norosí":{"dane_code":"13490"},
            "Pinillos":{"dane_code":"13549"},
            "Regidor":{"dane_code":"13580"},
            "Río Viejo":{"dane_code":"13600"},
            "San Estanislao":{"dane_code":"13647"},
            "San Fernando":{"dane_code":"13650"},
            "San Juan Nepomuceno":{"dane_code":"13657"},
            "Santa Catalina":{"dane_code":"13673"},
            "Santa Rosa":{"dane_code":"13683"},
            "Simití":{"dane_code":"13744"},
            "Soplaviento":{"dane_code":"13760"},
            "Talaigua Nuevo":{"dane_code":"13780"},
            "Tiquisio":{"dane_code":"13810"},
            "Turbaco":{"dane_code":"13836"},
            "Turbaná":{"dane_code":"13838"},
            "Villanueva":{"dane_code":"13873"},
            "Cartagena":{"dane_code":"13001"},
            "María la Baja":{"dane_code":"13442"},
            "San Cristóbal":{"dane_code":"13620"},
            "Zambrano":{"dane_code":"13894"},
            "Barranco de Loba":{"dane_code":"13074"},
            "Santa Rosa del Sur":{"dane_code":"13688"},
            "Hatillo de Loba":{"dane_code":"13300"},
        }
    },
    "Boyacá": {
        "dane_code":"15",
        "municipalities":{
            "Tibasosa":{"dane_code":"15806"},
            "Tunja":{"dane_code":"15001"},
            "Almeida":{"dane_code":"15022"},
            "Aquitania":{"dane_code":"15047"},
            "Arcabuco":{"dane_code":"15051"},
            "Berbeo":{"dane_code":"15090"},
            "Betéitiva":{"dane_code":"15092"},
            "Boavita":{"dane_code":"15097"},
            "Boyacá":{"dane_code":"15104"},
            "Briceño":{"dane_code":"15106"},
            "Buena Vista":{"dane_code":"15109"},
            "Busbanzá":{"dane_code":"15114"},
            "Caldas":{"dane_code":"15131"},
            "Campohermoso":{"dane_code":"15135"},
            "Cerinza":{"dane_code":"15162"},
            "Chinavita":{"dane_code":"15172"},
            "Chiquinquirá":{"dane_code":"15176"},
            "Chiscas":{"dane_code":"15180"},
            "Chita":{"dane_code":"15183"},
            "Chitaraque":{"dane_code":"15185"},
            "Chivatá":{"dane_code":"15187"},
            "Cómbita":{"dane_code":"15204"},
            "Coper":{"dane_code":"15212"},
            "Corrales":{"dane_code":"15215"},
            "Covarachía":{"dane_code":"15218"},
            "Cubará":{"dane_code":"15223"},
            "Cucaita":{"dane_code":"15224"},
            "Cuítiva":{"dane_code":"15226"},
            "Chíquiza":{"dane_code":"15232"},
            "Chivor":{"dane_code":"15236"},
            "Duitama":{"dane_code":"15238"},
            "El Cocuy":{"dane_code":"15244"},
            "El Espino":{"dane_code":"15248"},
            "Firavitoba":{"dane_code":"15272"},
            "Floresta":{"dane_code":"15276"},
            "Gachantivá":{"dane_code":"15293"},
            "Gameza":{"dane_code":"15296"},
            "Garagoa":{"dane_code":"15299"},
            "Guacamayas":{"dane_code":"15317"},
            "Guateque":{"dane_code":"15322"},
            "Guayatá":{"dane_code":"15325"},
            "Güicán":{"dane_code":"15332"},
            "Iza":{"dane_code":"15362"},
            "Jenesano":{"dane_code":"15367"},
            "Jericó":{"dane_code":"15368"},
            "Labranzagrande":{"dane_code":"15377"},
            "La Capilla":{"dane_code":"15380"},
            "La Victoria":{"dane_code":"15401"},
            "Macanal":{"dane_code":"15425"},
            "Maripí":{"dane_code":"15442"},
            "Miraflores":{"dane_code":"15455"},
            "Mongua":{"dane_code":"15464"},
            "Monguí":{"dane_code":"15466"},
            "Moniquirá":{"dane_code":"15469"},
            "Muzo":{"dane_code":"15480"},
            "Nobsa":{"dane_code":"15491"},
            "Nuevo Colón":{"dane_code":"15494"},
            "Oicatá":{"dane_code":"15500"},
            "Otanche":{"dane_code":"15507"},
            "Pachavita":{"dane_code":"15511"},
            "Páez":{"dane_code":"15514"},
            "Paipa":{"dane_code":"15516"},
            "Pajarito":{"dane_code":"15518"},
            "Panqueba":{"dane_code":"15522"},
            "Pauna":{"dane_code":"15531"},
            "Paya":{"dane_code":"15533"},
            "Pesca":{"dane_code":"15542"},
            "Pisba":{"dane_code":"15550"},
            "Puerto Boyacá":{"dane_code":"15572"},
            "Quípama":{"dane_code":"15580"},
            "Ramiriquí":{"dane_code":"15599"},
            "Ráquira":{"dane_code":"15600"},
            "Rondón":{"dane_code":"15621"},
            "Saboyá":{"dane_code":"15632"},
            "Sáchica":{"dane_code":"15638"},
            "Samacá":{"dane_code":"15646"},
            "San Eduardo":{"dane_code":"15660"},
            "San Mateo":{"dane_code":"15673"},
            "Santana":{"dane_code":"15686"},
            "Santa María":{"dane_code":"15690"},
            "Santa Sofía":{"dane_code":"15696"},
            "Sativanorte":{"dane_code":"15720"},
            "Sativasur":{"dane_code":"15723"},
            "Siachoque":{"dane_code":"15740"},
            "Soatá":{"dane_code":"15753"},
            "Socotá":{"dane_code":"15755"},
            "Socha":{"dane_code":"15757"},
            "Sogamoso":{"dane_code":"15759"},
            "Somondoco":{"dane_code":"15761"},
            "Sora":{"dane_code":"15762"},
            "Sotaquirá":{"dane_code":"15763"},
            "Soracá":{"dane_code":"15764"},
            "Susacón":{"dane_code":"15774"},
            "Sutamarchán":{"dane_code":"15776"},
            "Sutatenza":{"dane_code":"15778"},
            "Tasco":{"dane_code":"15790"},
            "Tenza":{"dane_code":"15798"},
            "Tibaná":{"dane_code":"15804"},
            "Tinjacá":{"dane_code":"15808"},
            "Tipacoque":{"dane_code":"15810"},
            "Toca":{"dane_code":"15814"},
            "Tópaga":{"dane_code":"15820"},
            "Tota":{"dane_code":"15822"},
            "Turmequé":{"dane_code":"15835"},
            "Tutazá":{"dane_code":"15839"},
            "Umbita":{"dane_code":"15842"},
            "Ventaquemada":{"dane_code":"15861"},
            "Viracachá":{"dane_code":"15879"},
            "Zetaquira":{"dane_code":"15897"},
            "La Uvita":{"dane_code":"15403"},
            "Belén":{"dane_code":"15087"},
            "Tununguá":{"dane_code":"15832"},
            "Motavita":{"dane_code":"15476"},
            "Ciénega":{"dane_code":"15189"},
            "Togüí":{"dane_code":"15816"},
            "Villa de Leyva":{"dane_code":"15407"},
            "Paz de Río":{"dane_code":"15537"},
            "Santa Rosa de Viterbo":{"dane_code":"15693"},
            "San Pablo de Borbur":{"dane_code":"15681"},
            "San Luis de Gaceno":{"dane_code":"15667"},
        }
    },
    "Caldas": {
        "dane_code":"17",
        "municipalities":{
            "Manizales":{"dane_code":"17001"},
            "Aguadas":{"dane_code":"17013"},
            "Anserma":{"dane_code":"17042"},
            "Aranzazu":{"dane_code":"17050"},
            "Belalcázar":{"dane_code":"17088"},
            "Chinchiná":{"dane_code":"17174"},
            "Filadelfia":{"dane_code":"17272"},
            "La Dorada":{"dane_code":"17380"},
            "La Merced":{"dane_code":"17388"},
            "Manzanares":{"dane_code":"17433"},
            "Marmato":{"dane_code":"17442"},
            "Marulanda":{"dane_code":"17446"},
            "Neira":{"dane_code":"17486"},
            "Norcasia":{"dane_code":"17495"},
            "Pácora":{"dane_code":"17513"},
            "Palestina":{"dane_code":"17524"},
            "Pensilvania":{"dane_code":"17541"},
            "Riosucio":{"dane_code":"17614"},
            "Risaralda":{"dane_code":"17616"},
            "Salamina":{"dane_code":"17653"},
            "Samaná":{"dane_code":"17662"},
            "San José":{"dane_code":"17665"},
            "Supía":{"dane_code":"17777"},
            "Victoria":{"dane_code":"17867"},
            "Villamaría":{"dane_code":"17873"},
            "Viterbo":{"dane_code":"17877"},
            "Marquetalia":{"dane_code":"17444"},
        }
    },
    "Caquetá":{
        "dane_code":"18",
        "municipalities":{
            "Milán":{"dane_code":"18460"},
            "Florencia":{"dane_code":"18001"},
            "Albania":{"dane_code":"18029"},
            "Curillo":{"dane_code":"18205"},
            "El Doncello":{"dane_code":"18247"},
            "El Paujil":{"dane_code":"18256"},
            "Morelia":{"dane_code":"18479"},
            "Puerto Rico":{"dane_code":"18592"},
            "La Montañita":{"dane_code":"18410"},
            "San Vicente del Caguán":{"dane_code":"18753"},
            "Solano":{"dane_code":"18756"},
            "Solita":{"dane_code":"18785"},
            "Valparaíso":{"dane_code":"18860"},
            "San José del Fragua":{"dane_code":"18610"},
            "Belén de Los Andaquies":{"dane_code":"18094"},
        }
    },
    "Casanare":{
        "dane_code":"18",
        "municipalities":{
            "Nunchía":{"dane_code":"85225"},
            "Maní":{"dane_code":"85139"},
            "Támara":{"dane_code":"85400"},
            "Orocué":{"dane_code":"85230"},
            "Yopal":{"dane_code":"85001"},
            "Aguazul":{"dane_code":"85010"},
            "Chámeza":{"dane_code":"85015"},
            "Hato Corozal":{"dane_code":"85125"},
            "La Salina":{"dane_code":"85136"},
            "Monterrey":{"dane_code":"85162"},
            "Pore":{"dane_code":"85263"},
            "Recetor":{"dane_code":"85279"},
            "Sabanalarga":{"dane_code":"85300"},
            "Sácama":{"dane_code":"85315"},
            "Tauramena":{"dane_code":"85410"},
            "Trinidad":{"dane_code":"85430"},
            "Villanueva":{"dane_code":"85440"},
            "San Luis de Gaceno":{"dane_code":"85325"},
            "Paz de Ariporo":{"dane_code":"85250"},
        }
    },
    "Cauca":{
        "dane_code":"19",
        "municipalities":{
            "Páez":{"dane_code":"19517"},
            "Popayán":{"dane_code":"19001"},
            "Almaguer":{"dane_code":"19022"},
            "Argelia":{"dane_code":"19050"},
            "Balboa":{"dane_code":"19075"},
            "Bolívar":{"dane_code":"19100"},
            "Buenos Aires":{"dane_code":"19110"},
            "Cajibío":{"dane_code":"19130"},
            "Caldono":{"dane_code":"19137"},
            "Caloto":{"dane_code":"19142"},
            "Corinto":{"dane_code":"19212"},
            "El Tambo":{"dane_code":"19256"},
            "Florencia":{"dane_code":"19290"},
            "Guachené":{"dane_code":"19300"},
            "Guapi":{"dane_code":"19318"},
            "Inzá":{"dane_code":"19355"},
            "Jambaló":{"dane_code":"19364"},
            "La Sierra":{"dane_code":"19392"},
            "La Vega":{"dane_code":"19397"},
            "López":{"dane_code":"19418"},
            "Mercaderes":{"dane_code":"19450"},
            "Miranda":{"dane_code":"19455"},
            "Morales":{"dane_code":"19473"},
            "Padilla":{"dane_code":"19513"},
            "Patía":{"dane_code":"19532"},
            "Piamonte":{"dane_code":"19533"},
            "Piendamó":{"dane_code":"19548"},
            "Puerto Tejada":{"dane_code":"19573"},
            "Puracé":{"dane_code":"19585"},
            "Rosas":{"dane_code":"19622"},
            "Santa Rosa":{"dane_code":"19701"},
            "Silvia":{"dane_code":"19743"},
            "Sotara":{"dane_code":"19760"},
            "Suárez":{"dane_code":"19780"},
            "Sucre":{"dane_code":"19785"},
            "Timbío":{"dane_code":"19807"},
            "Timbiquí":{"dane_code":"19809"},
            "Toribio":{"dane_code":"19821"},
            "Totoró":{"dane_code":"19824"},
            "Villa Rica":{"dane_code":"19845"},
            "Santander de Quilichao":{"dane_code":"19698"},
        }
    },
    "Cesar":{
        "dane_code":"20",
        "municipalities":{
            "Valledupar":{"dane_code":"20001"},
            "Aguachica":{"dane_code":"20011"},
            "Agustín Codazzi":{"dane_code":"20013"},
            "Astrea":{"dane_code":"20032"},
            "Becerril":{"dane_code":"20045"},
            "Bosconia":{"dane_code":"20060"},
            "Chimichagua":{"dane_code":"20175"},
            "Chiriguaná":{"dane_code":"20178"},
            "Curumaní":{"dane_code":"20228"},
            "El Copey":{"dane_code":"20238"},
            "El Paso":{"dane_code":"20250"},
            "Gamarra":{"dane_code":"20295"},
            "González":{"dane_code":"20310"},
            "La Gloria":{"dane_code":"20383"},
            "Manaure":{"dane_code":"20443"},
            "Pailitas":{"dane_code":"20517"},
            "Pelaya":{"dane_code":"20550"},
            "Pueblo Bello":{"dane_code":"20570"},
            "La Paz":{"dane_code":"20621"},
            "San Alberto":{"dane_code":"20710"},
            "San Diego":{"dane_code":"20750"},
            "San Martín":{"dane_code":"20770"},
            "Tamalameque":{"dane_code":"20787"},
            "Río de Oro":{"dane_code":"20614"},
            "La Jagua de Ibirico":{"dane_code":"20400"},
        }
    },
    "Chocó":{
        "dane_code":"27",
        "municipalities":{
            "Carmen del Darien":{"dane_code":"27150"},
            "Tadó":{"dane_code":"27787"},
            "Quibdó":{"dane_code":"27001"},
            "Acandí":{"dane_code":"27006"},
            "Alto Baudo":{"dane_code":"27025"},
            "Atrato":{"dane_code":"27050"},
            "Bagadó":{"dane_code":"27073"},
            "Bahía Solano":{"dane_code":"27075"},
            "Bajo Baudó":{"dane_code":"27077"},
            "Bojaya":{"dane_code":"27099"},
            "Unión Panamericana":{"dane_code":"27810"},
            "Cértegui":{"dane_code":"27160"},
            "Condoto":{"dane_code":"27205"},
            "Juradó":{"dane_code":"27372"},
            "Lloró":{"dane_code":"27413"},
            "Medio Atrato":{"dane_code":"27425"},
            "Medio Baudó":{"dane_code":"27430"},
            "Medio San Juan":{"dane_code":"27450"},
            "Nóvita":{"dane_code":"27491"},
            "Nuquí":{"dane_code":"27495"},
            "Río Iro":{"dane_code":"27580"},
            "Río Quito":{"dane_code":"27600"},
            "Riosucio":{"dane_code":"27615"},
            "Sipí":{"dane_code":"27745"},
            "Unguía":{"dane_code":"27800"},
            "Istmina":{"dane_code":"27361"},
            "El Litoral del San Juan":{"dane_code":"27250"},
            "El Cantón del San Pablo":{"dane_code":"27135"},
        }
    },
    "Córdoba":{
        "dane_code":"23",
        "municipalities":{
            "Montelíbano":{"dane_code":"23466"},
            "Montería":{"dane_code":"23001"},
            "Ayapel":{"dane_code":"23068"},
            "Buenavista":{"dane_code":"23079"},
            "Canalete":{"dane_code":"23090"},
            "Cereté":{"dane_code":"23162"},
            "Chimá":{"dane_code":"23168"},
            "Chinú":{"dane_code":"23182"},
            "Cotorra":{"dane_code":"23300"},
            "Lorica":{"dane_code":"23417"},
            "Los Córdobas":{"dane_code":"23419"},
            "Momil":{"dane_code":"23464"},
            "Moñitos":{"dane_code":"23500"},
            "Planeta Rica":{"dane_code":"23555"},
            "Pueblo Nuevo":{"dane_code":"23570"},
            "Puerto Escondido":{"dane_code":"23574"},
            "Purísima":{"dane_code":"23586"},
            "Sahagún":{"dane_code":"23660"},
            "San Andrés Sotavento":{"dane_code":"23670"},
            "San Antero":{"dane_code":"23672"},
            "San Pelayo":{"dane_code":"23686"},
            "Tierralta":{"dane_code":"23807"},
            "Tuchín":{"dane_code":"23815"},
            "Valencia":{"dane_code":"23855"},
            "La Apartada":{"dane_code":"23350"},
            "Puerto Libertador":{"dane_code":"23580"},
            "San Bernardo del Viento":{"dane_code":"23675"},
        }
    },
    "bogotá, d.c.":{
        "dane_code":"11",
        "municipalities":{
            "Bogotá":{"dane_code":"11001"},
        }
    },¶ 
    "Cundinamarca":{
        "dane_code":"25",
        "municipalities":{
            "Bogotá":{"dane_code":"11001"},
            "Albán":{"dane_code":"25019"},
            "Anolaima":{"dane_code":"25040"},
            "Chía":{"dane_code":"25175"},
            "El Peñón":{"dane_code":"25258"},
            "Sopó":{"dane_code":"25758"},
            "Gama":{"dane_code":"25299"},
            "Sasaima":{"dane_code":"25718"},
            "Yacopí":{"dane_code":"25885"},
            "Anapoima":{"dane_code":"25035"},
            "Arbeláez":{"dane_code":"25053"},
            "Beltrán":{"dane_code":"25086"},
            "Bituima":{"dane_code":"25095"},
            "Bojacá":{"dane_code":"25099"},
            "Cabrera":{"dane_code":"25120"},
            "Cachipay":{"dane_code":"25123"},
            "Cajicá":{"dane_code":"25126"},
            "Caparrapí":{"dane_code":"25148"},
            "Caqueza":{"dane_code":"25151"},
            "Chaguaní":{"dane_code":"25168"},
            "Chipaque":{"dane_code":"25178"},
            "Choachí":{"dane_code":"25181"},
            "Chocontá":{"dane_code":"25183"},
            "Cogua":{"dane_code":"25200"},
            "Cota":{"dane_code":"25214"},
            "Cucunubá":{"dane_code":"25224"},
            "El Colegio":{"dane_code":"25245"},
            "El Rosal":{"dane_code":"25260"},
            "Fomeque":{"dane_code":"25279"},
            "Fosca":{"dane_code":"25281"},
            "Funza":{"dane_code":"25286"},
            "Fúquene":{"dane_code":"25288"},
            "Gachala":{"dane_code":"25293"},
            "Gachancipá":{"dane_code":"25295"},
            "Gachetá":{"dane_code":"25297"},
            "Girardot":{"dane_code":"25307"},
            "Granada":{"dane_code":"25312"},
            "Guachetá":{"dane_code":"25317"},
            "Guaduas":{"dane_code":"25320"},
            "Guasca":{"dane_code":"25322"},
            "Guataquí":{"dane_code":"25324"},
            "Guatavita":{"dane_code":"25326"},
            "Fusagasugá":{"dane_code":"25290"},
            "Guayabetal":{"dane_code":"25335"},
            "Gutiérrez":{"dane_code":"25339"},
            "Jerusalén":{"dane_code":"25368"},
            "Junín":{"dane_code":"25372"},
            "La Calera":{"dane_code":"25377"},
            "La Mesa":{"dane_code":"25386"},
            "La Palma":{"dane_code":"25394"},
            "La Peña":{"dane_code":"25398"},
            "La Vega":{"dane_code":"25402"},
            "Lenguazaque":{"dane_code":"25407"},
            "Macheta":{"dane_code":"25426"},
            "Madrid":{"dane_code":"25430"},
            "Manta":{"dane_code":"25436"},
            "Medina":{"dane_code":"25438"},
            "Mosquera":{"dane_code":"25473"},
            "Nariño":{"dane_code":"25483"},
            "Nemocón":{"dane_code":"25486"},
            "Nilo":{"dane_code":"25488"},
            "Nimaima":{"dane_code":"25489"},
            "Nocaima":{"dane_code":"25491"},
            "Venecia":{"dane_code":"25506"},
            "Pacho":{"dane_code":"25513"},
            "Paime":{"dane_code":"25518"},
            "Pandi":{"dane_code":"25524"},
            "Paratebueno":{"dane_code":"25530"},
            "Pasca":{"dane_code":"25535"},
            "Puerto Salgar":{"dane_code":"25572"},
            "Pulí":{"dane_code":"25580"},
            "Quebradanegra":{"dane_code":"25592"},
            "Quetame":{"dane_code":"25594"},
            "Quipile":{"dane_code":"25596"},
            "Apulo":{"dane_code":"25599"},
            "Ricaurte":{"dane_code":"25612"},
            "San Bernardo":{"dane_code":"25649"},
            "San Cayetano":{"dane_code":"25653"},
            "San Francisco":{"dane_code":"25658"},
            "Zipaquirá":{"dane_code":"25899"},
            "Sesquilé":{"dane_code":"25736"},
            "Sibaté":{"dane_code":"25740"},
            "Silvania":{"dane_code":"25743"},
            "Simijaca":{"dane_code":"25745"},
            "Soacha":{"dane_code":"25754"},
            "Subachoque":{"dane_code":"25769"},
            "Suesca":{"dane_code":"25772"},
            "Supatá":{"dane_code":"25777"},
            "Susa":{"dane_code":"25779"},
            "Sutatausa":{"dane_code":"25781"},
            "Tabio":{"dane_code":"25785"},
            "Tausa":{"dane_code":"25793"},
            "Tena":{"dane_code":"25797"},
            "Tenjo":{"dane_code":"25799"},
            "Tibacuy":{"dane_code":"25805"},
            "Tibirita":{"dane_code":"25807"},
            "Tocaima":{"dane_code":"25815"},
            "Tocancipá":{"dane_code":"25817"},
            "Topaipí":{"dane_code":"25823"},
            "Ubalá":{"dane_code":"25839"},
            "Ubaque":{"dane_code":"25841"},
            "Une":{"dane_code":"25845"},
            "Útica":{"dane_code":"25851"},
            "Vianí":{"dane_code":"25867"},
            "Villagómez":{"dane_code":"25871"},
            "Villapinzón":{"dane_code":"25873"},
            "Villeta":{"dane_code":"25875"},
            "Viotá":{"dane_code":"25878"},
            "Zipacón":{"dane_code":"25898"},
            "Facatativá":{"dane_code":"25269"},
            "San Juan de Río Seco":{"dane_code":"25662"},
            "Villa de San Diego de Ubate":{"dane_code":"25843"},
            "Guayabal de Siquima":{"dane_code":"25328"},
        }
    },
    "Guainía":{
        "dane_code":"94",
        "municipalities":{
            "Inírida":{"dane_code":"94001"},
            "Barranco Minas":{"dane_code":"94343"},
            "Mapiripana":{"dane_code":"94663"},
            "San Felipe":{"dane_code":"94883"},
            "Puerto Colombia":{"dane_code":"94884"},
            "La Guadalupe":{"dane_code":"94885"},
            "Cacahual":{"dane_code":"94886"},
            "Pana Pana":{"dane_code":"94887"},
            "Morichal":{"dane_code":"94888"},
        }
    },
    "Guaviare":{
        "dane_code":"95",
        "municipalities":{
            "Calamar":{"dane_code":"95015"},
            "San José del Guaviare":{"dane_code":"95001"},
            "Miraflores":{"dane_code":"95200"},
        }
    },
    "Huila":{
        "dane_code":"41",
        "municipalities":{
            "Neiva":{"dane_code":"41001"},
            "Acevedo":{"dane_code":"41006"},
            "Agrado":{"dane_code":"41013"},
            "Aipe":{"dane_code":"41016"},
            "Algeciras":{"dane_code":"41020"},
            "Altamira":{"dane_code":"41026"},
            "Baraya":{"dane_code":"41078"},
            "Campoalegre":{"dane_code":"41132"},
            "Colombia":{"dane_code":"41206"},
            "Elías":{"dane_code":"41244"},
            "Garzón":{"dane_code":"41298"},
            "Gigante":{"dane_code":"41306"},
            "Guadalupe":{"dane_code":"41319"},
            "Hobo":{"dane_code":"41349"},
            "Iquira":{"dane_code":"41357"},
            "Isnos":{"dane_code":"41359"},
            "La Argentina":{"dane_code":"41378"},
            "La Plata":{"dane_code":"41396"},
            "Nátaga":{"dane_code":"41483"},
            "Oporapa":{"dane_code":"41503"},
            "Paicol":{"dane_code":"41518"},
            "Palermo":{"dane_code":"41524"},
            "Palestina":{"dane_code":"41530"},
            "Pital":{"dane_code":"41548"},
            "Pitalito":{"dane_code":"41551"},
            "Rivera":{"dane_code":"41615"},
            "Saladoblanco":{"dane_code":"41660"},
            "Santa María":{"dane_code":"41676"},
            "Suaza":{"dane_code":"41770"},
            "Tarqui":{"dane_code":"41791"},
            "Tesalia":{"dane_code":"41797"},
            "Tello":{"dane_code":"41799"},
            "Teruel":{"dane_code":"41801"},
            "Timaná":{"dane_code":"41807"},
            "Villavieja":{"dane_code":"41872"},
            "Yaguará":{"dane_code":"41885"},
        }
    },
    "La Guajira":{
        "dane_code":"44",
        "municipalities":{
            "Riohacha":{"dane_code":"44001"},
            "Albania":{"dane_code":"44035"},
            "Barrancas":{"dane_code":"44078"},
            "Dibula":{"dane_code":"44090"},
            "Distracción":{"dane_code":"44098"},
            "El Molino":{"dane_code":"44110"},
            "Fonseca":{"dane_code":"44279"},
            "Hatonuevo":{"dane_code":"44378"},
            "Maicao":{"dane_code":"44430"},
            "Manaure":{"dane_code":"44560"},
            "Uribia":{"dane_code":"44847"},
            "Urumita":{"dane_code":"44855"},
            "Villanueva":{"dane_code":"44874"},
            "La Jagua del Pilar":{"dane_code":"44420"},
        }
    },
    "Magdalena":{
        "dane_code":"47",
        "municipalities":{
            "Santa Bárbara de Pinto":{"dane_code":"47720"},
            "Pueblo Viejo":{"dane_code":"47570"},
            "Santa Marta":{"dane_code":"47001"},
            "Algarrobo":{"dane_code":"47030"},
            "Aracataca":{"dane_code":"47053"},
            "Ariguaní":{"dane_code":"47058"},
            "Cerro San Antonio":{"dane_code":"47161"},
            "Chivolo":{"dane_code":"47170"},
            "Concordia":{"dane_code":"47205"},
            "El Banco":{"dane_code":"47245"},
            "El Piñon":{"dane_code":"47258"},
            "El Retén":{"dane_code":"47268"},
            "Fundación":{"dane_code":"47288"},
            "Guamal":{"dane_code":"47318"},
            "Nueva Granada":{"dane_code":"47460"},
            "Pedraza":{"dane_code":"47541"},
            "Pivijay":{"dane_code":"47551"},
            "Plato":{"dane_code":"47555"},
            "Remolino":{"dane_code":"47605"},
            "Salamina":{"dane_code":"47675"},
            "San Zenón":{"dane_code":"47703"},
            "Santa Ana":{"dane_code":"47707"},
            "Sitionuevo":{"dane_code":"47745"},
            "Tenerife":{"dane_code":"47798"},
            "Zapayán":{"dane_code":"47960"},
            "Zona Bananera":{"dane_code":"47980"},
            "Ciénaga":{"dane_code":"47189"},
            "San Sebastián de Buenavista":{"dane_code":"47692"},
            "Sabanas de San Angel":{"dane_code":"47660"},
        }
    },
    "Meta":{
        "dane_code":"50",
        "municipalities":{
            "Castilla la Nueva":{"dane_code":"50150"},
            "Villavicencio":{"dane_code":"50001"},
            "Acacias":{"dane_code":"50006"},
            "Cabuyaro":{"dane_code":"50124"},
            "Cubarral":{"dane_code":"50223"},
            "Cumaral":{"dane_code":"50226"},
            "El Calvario":{"dane_code":"50245"},
            "El Castillo":{"dane_code":"50251"},
            "El Dorado":{"dane_code":"50270"},
            "Granada":{"dane_code":"50313"},
            "Guamal":{"dane_code":"50318"},
            "Mapiripán":{"dane_code":"50325"},
            "Mesetas":{"dane_code":"50330"},
            "La Macarena":{"dane_code":"50350"},
            "Uribe":{"dane_code":"50370"},
            "Lejanías":{"dane_code":"50400"},
            "Puerto Concordia":{"dane_code":"50450"},
            "Puerto Gaitán":{"dane_code":"50568"},
            "Puerto López":{"dane_code":"50573"},
            "Puerto Lleras":{"dane_code":"50577"},
            "Puerto Rico":{"dane_code":"50590"},
            "Restrepo":{"dane_code":"50606"},
            "San Juanito":{"dane_code":"50686"},
            "San Martín":{"dane_code":"50689"},
            "Vista Hermosa":{"dane_code":"50711"},
            "Barranca de Upía":{"dane_code":"50110"},
            "Fuente de Oro":{"dane_code":"50287"},
            "San Carlos de Guaroa":{"dane_code":"50680"},
        }
    },
    "Nariño":{
        "dane_code":"52",
        "municipalities":{
            "Buesaco":{"dane_code":"52110"},
            "San Andrés de Tumaco":{"dane_code":"52835"},
            "Belén":{"dane_code":"52083"},
            "Chachagüí":{"dane_code":"52240"},
            "Arboleda":{"dane_code":"52051"},
            "Pasto":{"dane_code":"52001"},
            "Albán":{"dane_code":"52019"},
            "Aldana":{"dane_code":"52022"},
            "Ancuyá":{"dane_code":"52036"},
            "Barbacoas":{"dane_code":"52079"},
            "Colón":{"dane_code":"52203"},
            "Consaca":{"dane_code":"52207"},
            "Contadero":{"dane_code":"52210"},
            "Córdoba":{"dane_code":"52215"},
            "Cuaspud":{"dane_code":"52224"},
            "Cumbal":{"dane_code":"52227"},
            "Cumbitara":{"dane_code":"52233"},
            "El Charco":{"dane_code":"52250"},
            "El Peñol":{"dane_code":"52254"},
            "El Rosario":{"dane_code":"52256"},
            "El Tambo":{"dane_code":"52260"},
            "Funes":{"dane_code":"52287"},
            "Guachucal":{"dane_code":"52317"},
            "Guaitarilla":{"dane_code":"52320"},
            "Gualmatán":{"dane_code":"52323"},
            "Iles":{"dane_code":"52352"},
            "Imués":{"dane_code":"52354"},
            "Ipiales":{"dane_code":"52356"},
            "La Cruz":{"dane_code":"52378"},
            "La Florida":{"dane_code":"52381"},
            "La Llanada":{"dane_code":"52385"},
            "La Tola":{"dane_code":"52390"},
            "La Unión":{"dane_code":"52399"},
            "Leiva":{"dane_code":"52405"},
            "Linares":{"dane_code":"52411"},
            "Los Andes":{"dane_code":"52418"},
            "Magüí":{"dane_code":"52427"},
            "Mallama":{"dane_code":"52435"},
            "Mosquera":{"dane_code":"52473"},
            "Nariño":{"dane_code":"52480"},
            "Olaya Herrera":{"dane_code":"52490"},
            "Ospina":{"dane_code":"52506"},
            "Francisco Pizarro":{"dane_code":"52520"},
            "Policarpa":{"dane_code":"52540"},
            "Potosí":{"dane_code":"52560"},
            "Providencia":{"dane_code":"52565"},
            "Puerres":{"dane_code":"52573"},
            "Pupiales":{"dane_code":"52585"},
            "Ricaurte":{"dane_code":"52612"},
            "Roberto Payán":{"dane_code":"52621"},
            "Samaniego":{"dane_code":"52678"},
            "Sandoná":{"dane_code":"52683"},
            "San Bernardo":{"dane_code":"52685"},
            "San Lorenzo":{"dane_code":"52687"},
            "San Pablo":{"dane_code":"52693"},
            "Santa Bárbara":{"dane_code":"52696"},
            "Sapuyes":{"dane_code":"52720"},
            "Taminango":{"dane_code":"52786"},
            "Tangua":{"dane_code":"52788"},
            "Santacruz":{"dane_code":"52699"},
            "Túquerres":{"dane_code":"52838"},
            "Yacuanquer":{"dane_code":"52885"},
        }
    },
    "Norte de Santander":{
        "dane_code":"",
        "municipalities":{
            "Pamplona":{"dane_code":"54518"},
            "Pamplonita":{"dane_code":"54520"},
            "Cúcuta":{"dane_code":"54001"},
            "El Carmen":{"dane_code":"54245"},
        }
    },
    "Putumayo":{
        "dane_code":"86",
        "municipalities":{
            "Puerto Asís":{"dane_code":"86568"},
            "Villagarzón":{"dane_code":"86885"},
            "Mocoa":{"dane_code":"86001"},
            "Colón":{"dane_code":"86219"},
            "Orito":{"dane_code":"86320"},
            "Puerto Caicedo":{"dane_code":"86569"},
            "Puerto Guzmán":{"dane_code":"86571"},
            "Leguízamo":{"dane_code":"86573"},
            "Sibundoy":{"dane_code":"86749"},
            "San Francisco":{"dane_code":"86755"},
            "San Miguel":{"dane_code":"86757"},
            "Santiago":{"dane_code":"86760"},
        }
    },
    "Quindío":{
        "dane_code":"63",
        "municipalities":{
            "Calarcá":{"dane_code":"63130"},
            "Génova":{"dane_code":"63302"},
            "Armenia":{"dane_code":"63001"},
            "Buenavista":{"dane_code":"63111"},
            "Circasia":{"dane_code":"63190"},
            "Córdoba":{"dane_code":"63212"},
            "Filandia":{"dane_code":"63272"},
            "La Tebaida":{"dane_code":"63401"},
            "Montenegro":{"dane_code":"63470"},
            "Pijao":{"dane_code":"63548"},
            "Quimbaya":{"dane_code":"63594"},
            "Salento":{"dane_code":"63690"},
        }
    },
    "Risaralda":{
        "dane_code":"66",
        "municipalities":{
            "Pereira":{"dane_code":"66001"},
            "Apía":{"dane_code":"66045"},
            "Balboa":{"dane_code":"66075"},
            "Dosquebradas":{"dane_code":"66170"},
            "Guática":{"dane_code":"66318"},
            "La Celia":{"dane_code":"66383"},
            "La Virginia":{"dane_code":"66400"},
            "Marsella":{"dane_code":"66440"},
            "Mistrató":{"dane_code":"66456"},
            "Pueblo Rico":{"dane_code":"66572"},
            "Quinchía":{"dane_code":"66594"},
            "Santuario":{"dane_code":"66687"},
            "Santa Rosa de Cabal":{"dane_code":"66682"},
        }
    },
    "Santander":{
        "dane_code":"68",
        "municipalities":{
            "Chimá":{"dane_code":"68176"},
            "Capitanejo":{"dane_code":"68147"},
            "El Peñón":{"dane_code":"68250"},
            "Puerto Wilches":{"dane_code":"68575"},
            "Puerto Parra":{"dane_code":"68573"},
            "Bucaramanga":{"dane_code":"68001"},
            "Aguada":{"dane_code":"68013"},
            "Albania":{"dane_code":"68020"},
            "Aratoca":{"dane_code":"68051"},
            "Barbosa":{"dane_code":"68077"},
            "Barichara":{"dane_code":"68079"},
            "Barrancabermeja":{"dane_code":"68081"},
            "Betulia":{"dane_code":"68092"},
            "Bolívar":{"dane_code":"68101"},
            "Cabrera":{"dane_code":"68121"},
            "California":{"dane_code":"68132"},
            "Carcasí":{"dane_code":"68152"},
            "Cepitá":{"dane_code":"68160"},
            "Cerrito":{"dane_code":"68162"},
            "Charalá":{"dane_code":"68167"},
            "Charta":{"dane_code":"68169"},
            "Chipatá":{"dane_code":"68179"},
            "Cimitarra":{"dane_code":"68190"},
            "Concepción":{"dane_code":"68207"},
            "Confines":{"dane_code":"68209"},
            "Contratación":{"dane_code":"68211"},
            "Coromoro":{"dane_code":"68217"},
            "Curití":{"dane_code":"68229"},
            "El Guacamayo":{"dane_code":"68245"},
            "El Playón":{"dane_code":"68255"},
            "Encino":{"dane_code":"68264"},
            "Enciso":{"dane_code":"68266"},
            "Florián":{"dane_code":"68271"},
            "Floridablanca":{"dane_code":"68276"},
            "Galán":{"dane_code":"68296"},
            "Gambita":{"dane_code":"68298"},
            "Girón":{"dane_code":"68307"},
            "Guaca":{"dane_code":"68318"},
            "Guadalupe":{"dane_code":"68320"},
            "Guapotá":{"dane_code":"68322"},
            "Guavatá":{"dane_code":"68324"},
            "Güepsa":{"dane_code":"68327"},
            "Jesús María":{"dane_code":"68368"},
            "Jordán":{"dane_code":"68370"},
            "La Belleza":{"dane_code":"68377"},
            "Landázuri":{"dane_code":"68385"},
            "La Paz":{"dane_code":"68397"},
            "Lebríja":{"dane_code":"68406"},
            "Los Santos":{"dane_code":"68418"},
            "Macaravita":{"dane_code":"68425"},
            "Málaga":{"dane_code":"68432"},
            "Matanza":{"dane_code":"68444"},
            "Mogotes":{"dane_code":"68464"},
            "Molagavita":{"dane_code":"68468"},
            "Ocamonte":{"dane_code":"68498"},
            "Oiba":{"dane_code":"68500"},
            "Onzaga":{"dane_code":"68502"},
            "Palmar":{"dane_code":"68522"},
            "Páramo":{"dane_code":"68533"},
            "Piedecuesta":{"dane_code":"68547"},
            "Pinchote":{"dane_code":"68549"},
            "Puente Nacional":{"dane_code":"68572"},
            "Rionegro":{"dane_code":"68615"},
            "San Andrés":{"dane_code":"68669"},
            "San Gil":{"dane_code":"68679"},
            "San Joaquín":{"dane_code":"68682"},
            "San Miguel":{"dane_code":"68686"},
            "Santa Bárbara":{"dane_code":"68705"},
            "Simacota":{"dane_code":"68745"},
            "Socorro":{"dane_code":"68755"},
            "Suaita":{"dane_code":"68770"},
            "Sucre":{"dane_code":"68773"},
            "Suratá":{"dane_code":"68780"},
            "Tona":{"dane_code":"68820"},
            "Vélez":{"dane_code":"68861"},
            "Vetas":{"dane_code":"68867"},
            "Villanueva":{"dane_code":"68872"},
            "Zapatoca":{"dane_code":"68895"},
            "Palmas del Socorro":{"dane_code":"68524"},
            "San Vicente de Chucurí":{"dane_code":"68689"},
            "San José de Miranda":{"dane_code":"68684"},
            "Santa Helena del Opón":{"dane_code":"68720"},
        }
    },
    "Sucre":{
        "dane_code":"70",
        "municipalities":{
            "Sampués":{"dane_code":"70670"},
            "Corozal":{"dane_code":"70215"},
            "Sincelejo":{"dane_code":"70001"},
            "Buenavista":{"dane_code":"70110"},
            "Caimito":{"dane_code":"70124"},
            "Coloso":{"dane_code":"70204"},
            "Coveñas":{"dane_code":"70221"},
            "Chalán":{"dane_code":"70230"},
            "El Roble":{"dane_code":"70233"},
            "Galeras":{"dane_code":"70235"},
            "Guaranda":{"dane_code":"70265"},
            "La Unión":{"dane_code":"70400"},
            "Los Palmitos":{"dane_code":"70418"},
            "Majagual":{"dane_code":"70429"},
            "Morroa":{"dane_code":"70473"},
            "Ovejas":{"dane_code":"70508"},
            "Palmito":{"dane_code":"70523"},
            "San Benito Abad":{"dane_code":"70678"},
            "San Marcos":{"dane_code":"70708"},
            "San Onofre":{"dane_code":"70713"},
            "San Pedro":{"dane_code":"70717"},
            "Sucre":{"dane_code":"70771"},
            "Tolú Viejo":{"dane_code":"70823"},
            "San Luis de Sincé":{"dane_code":"70742"},
        }
    },
    "Tolima":{
        "dane_code":"73",
        "municipalities":{
            "Casabianca":{"dane_code":"73152"},
            "Anzoátegui":{"dane_code":"73043"},
            "Ibagué":{"dane_code":"73001"},
            "Líbano":{"dane_code":"73411"},
            "Lérida":{"dane_code":"73408"},
            "Suárez":{"dane_code":"73770"},
            "Alpujarra":{"dane_code":"73024"},
            "Alvarado":{"dane_code":"73026"},
            "Ambalema":{"dane_code":"73030"},
            "Armero":{"dane_code":"73055"},
            "Ataco":{"dane_code":"73067"},
            "Cajamarca":{"dane_code":"73124"},
            "Chaparral":{"dane_code":"73168"},
            "Coello":{"dane_code":"73200"},
            "Coyaima":{"dane_code":"73217"},
            "Cunday":{"dane_code":"73226"},
            "Dolores":{"dane_code":"73236"},
            "Espinal":{"dane_code":"73268"},
            "Falan":{"dane_code":"73270"},
            "Flandes":{"dane_code":"73275"},
            "Fresno":{"dane_code":"73283"},
            "Guamo":{"dane_code":"73319"},
            "Herveo":{"dane_code":"73347"},
            "Honda":{"dane_code":"73349"},
            "Icononzo":{"dane_code":"73352"},
            "Mariquita":{"dane_code":"73443"},
            "Melgar":{"dane_code":"73449"},
            "Murillo":{"dane_code":"73461"},
            "Natagaima":{"dane_code":"73483"},
            "Ortega":{"dane_code":"73504"},
            "Palocabildo":{"dane_code":"73520"},
            "Piedras":{"dane_code":"73547"},
            "Planadas":{"dane_code":"73555"},
            "Prado":{"dane_code":"73563"},
            "Purificación":{"dane_code":"73585"},
            "Rio Blanco":{"dane_code":"73616"},
            "Roncesvalles":{"dane_code":"73622"},
            "Rovira":{"dane_code":"73624"},
            "Saldaña":{"dane_code":"73671"},
            "Santa Isabel":{"dane_code":"73686"},
            "Venadillo":{"dane_code":"73861"},
            "Villahermosa":{"dane_code":"73870"},
            "Villarrica":{"dane_code":"73873"},
            "Valle de San Juan":{"dane_code":"73854"},
        }
    },
    "Valle del Cauca":{
        "dane_code":"76",
        "municipalities":{
            "Santiago de Cali":{"dane_code":"76001"},
            "Cali":{"dane_code":"76001"},
            "Tuluá":{"dane_code":"76834"},
            "Florida":{"dane_code":"76275"},
            "Jamundí":{"dane_code":"76364"},
            "Buenaventura":{"dane_code":"76109"},
        }
    },
    "Valle":{
        "dane_code":"76",
        "municipalities":{
            "Santiago de Cali":{"dane_code":"76001"},
            "Cali":{"dane_code":"76001"},
            "Tuluá":{"dane_code":"76834"},
            "Florida":{"dane_code":"76275"},
            "Jamundí":{"dane_code":"76364"},
            "Buenaventura":{"dane_code":"76109"},
        }
    },
    "Vaupés":{
        "dane_code":"97",
        "municipalities":{
            "Yavaraté":{"dane_code":"97889"},
            "Mitú":{"dane_code":"97001"},
            "Caruru":{"dane_code":"97161"},
            "Pacoa":{"dane_code":"97511"},
            "Taraira":{"dane_code":"97666"},
            "Papunaua":{"dane_code":"97777"},
        }
    },
    "Vichada":{
        "dane_code":"99",
        "municipalities":{
            "Puerto Carreño":{"dane_code":"99001"},
            "La Primavera":{"dane_code":"99524"},
            "Santa Rosalía":{"dane_code":"99624"},
            "Cumaribo":{"dane_code":"99773"},
        }
    }
}